@@ -82,12 +82,14 @@ class IndexValProcessLongTerm:
 
         index_list = self.result.index_id.unique()
         dic = {'pb_mrq': 'pb_pct', 'pe_ttm': 'pe_pct', 'roe': 'roe_pct'}
+        l = list(dic.values())
         pct_list = [0.3, 0.7]
         res = []
         for index_id in index_list:
             _df = self.result[self.result['index_id'] == index_id].set_index('datetime')
             if _df.shape[0] < 242 * 5:
-                continue
+                _df.loc[:,l] = None
+                res.append(_df.reset_index())
             else:
                 for index_val, index_pct in dic.items():
                     _res = []
