@@ -13,6 +13,7 @@ from ...manager.score import FundScoreManager
 from ...wrapper.mysql import DerivedDatabaseConnector
 from ...view.derived_models import *
 from .derived_data_helper import DerivedDataHelper
+from ...api.derived import DerivedDataApi
 
 class FundIndicatorProcessor(object):
 
@@ -293,7 +294,7 @@ class FundIndicatorProcessor(object):
         result = [ _ for _ in result if not _ is None]
         self.result = pd.concat(result, axis=0, sort=True)
 
-    def calculate_update(self):
+    def calculate_update(self, dt):
         self.fund_fee = self.fund_info[['fund_id','manage_fee','trustee_fee']].set_index('fund_id').fillna(0).sum(axis = 1)
         result = []
         index_list = self.index_list
@@ -314,7 +315,7 @@ class FundIndicatorProcessor(object):
             fund_ret = self.fund_ret[fund_list].copy()
             index_ret = self.index_ret[[index_id]]
             for fund_id in fund_list:
-                result.append(self._process_fund_indicator_update(fund_id, time_range, fund_ret, index_id, index_ret))
+                result.append(self._process_fund_indicator_update(fund_id, time_range, fund_ret.loc[:dt], index_id, index_ret.loc[:dt]))
             print(f'index {index_id} finish fund number fund_list {len(fund_list)} fund_list_1 {len(fund_list_1)} fund_list_2 {len(fund_list_2)}')
             for fund_id in fund_list:
                 fund_index_dict[fund_id] = index_id
@@ -332,8 +333,16 @@ class FundIndicatorProcessor(object):
             start_date = datetime.datetime.strftime(start_date, '%Y%m%d')
 
             self.init(start_date=start_date, end_date=end_date)
-            self.calculate_update()
-            df = self.result[self.result['datetime'] == end_date_dt]
+
+            self._update_begin_date = self._dm.dts.trading_days[self._dm.dts.trading_days.datetime<self.end_date] 
+            update_dt_list = self._update_begin_date.datetime.values[-3:].tolist()
+            self.fac_result = []
+            for dt in update_dt_list:
+                self.calculate_update(dt)
+                self.fac_result.append(self.result)
+            df = pd.concat(self.fac_result)
+            df = df[df.datetime.isin(update_dt_list)]
+            DerivedDataApi().delete_fund_indicator_with_dt(date_list=update_dt_list)
             self._data_helper._upload_derived(df, FundIndicator.__table__.name)
         except Exception as e:
             print(e)
