@@ -710,6 +710,7 @@ class FOFNav(FOFBase):
     nav = Column(DOUBLE(asdecimal=False), nullable=False)   # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))         # 累计净值
     adjusted_nav = Column(DOUBLE(asdecimal=False))          # 复权净值
+    ta_factor = Column(DOUBLE(asdecimal=False))             # 复权因子
     volume = Column(DOUBLE(asdecimal=False))                # 份额
     mv = Column(DOUBLE(asdecimal=False))                    # 市值
     ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
@@ -738,18 +739,19 @@ class FOFNavCalc(FOFBase):
     __tablename__ = 'fof_nav_calc'
 
     fof_id = Column(CHAR(16), primary_key=True)             # 产品ID
+    manager_id = Column(CHAR(32), primary_key=True)         # 管理端ID
     datetime = Column(DATE, primary_key=True)               # 日期
     nav = Column(DOUBLE(asdecimal=False), nullable=False)   # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))         # 累计净值
     adjusted_nav = Column(DOUBLE(asdecimal=False))          # 复权净值
-    volume = Column(DOUBLE(asdecimal=False))                # 份额
-    mv = Column(DOUBLE(asdecimal=False))                    # 市值
-    interest = Column(DOUBLE(asdecimal=False))              # 利息
-    management_fee = Column(DOUBLE(asdecimal=False))        # 管理费
-    custodian_fee = Column(DOUBLE(asdecimal=False))         # 托管费
-    administrative_fee = Column(DOUBLE(asdecimal=False))    # 行政管理费
+    ta_factor = Column(DOUBLE(asdecimal=False))             # 复权因子
+    volume = Column(DOUBLE(asdecimal=False))                # 总份额
+    mv = Column(DOUBLE(asdecimal=False))                    # 总市值(净资产)
+    interest = Column(DOUBLE(asdecimal=False))              # 当日利息
+    management_fee = Column(DOUBLE(asdecimal=False))        # 当日管理费
+    custodian_fee = Column(DOUBLE(asdecimal=False))         # 当日托管费
+    administrative_fee = Column(DOUBLE(asdecimal=False))    # 当日行政服务费
     ret = Column(DOUBLE(asdecimal=False))                   # 累计收益率
-    manager_id = Column(CHAR(32))                           # 管理端ID
 
 
 class FOFPosition(FOFBase):
@@ -761,7 +763,9 @@ class FOFPosition(FOFBase):
     manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
     datetime = Column(DATE, primary_key=True)  # 日期
     position = Column(TEXT, nullable=False)  # 持仓信息
-    total_current = Column(DOUBLE(asdecimal=False))            # 流动性资产及负债总计
+    total_current = Column(DOUBLE(asdecimal=False))  # 流动性资产及负债总计
+    other_assets = Column(DOUBLE(asdecimal=False))  # 其他资产
+    deposit_in_bank = Column(DOUBLE(asdecimal=False))  # 银行存款
 
 
 class FOFInvestorData(FOFBase):
@@ -781,6 +785,7 @@ class FOFPositionDetail(FOFBase):
     __tablename__ = 'fof_position_detail'
 
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
+    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
     datetime = Column(DATE, primary_key=True)  # 日期
     fund_id = Column(CHAR(10), primary_key=True) # 基金ID
     asset_type = Column(Enum(HoldingAssetType), nullable=False)  # 资产类型
