@@ -20,7 +20,6 @@ from .asset_helper import SAAHelper, TAAHelper, FAHelper, TAAStatusMode
 from ...util.calculator import Calculator
 from ...constant import IndClassType
 
-
 CURRENT_PLATFORM = platform.system()
 if CURRENT_PLATFORM == 'Darwin':
     mpl.rcParams['font.family'] = ['Heiti TC']
@@ -897,6 +896,7 @@ class ReportHelper:
         fund_info = m.dts.fund_info
         active_fund_info = m.dts.active_fund_info
         index_info = m.dts.index_info
+        fund_size = m.dts.fund_size
         _index_price = index_price.loc[begin_date:today]
         _index_price = _index_price / _index_price.iloc[0]
         last_day = _index_price.index.values[-1]
@@ -925,12 +925,20 @@ class ReportHelper:
         name_dict = fund_info.set_index('fund_id').to_dict()['desc_name']
         name_dict.update(index_info.set_index('index_id').to_dict()['desc_name'])
         price_df = price_df.rename(columns=name_dict)
-        indicator = m.dts.index_fund_indicator_pack.loc[index_id].loc[last_day].loc[top_fund_list][['alpha','beta','fund_size','track_err']].reset_index()
+        indicator = m.dts.index_fund_indicator_pack.loc[index_id].loc[last_day].loc[top_fund_list][['alpha','beta','track_err']].reset_index()
         indicator.loc[:,'rank'] = indicator.fund_id.map(lambda x :score_list.index(x) + 1)
         indicator['desc_name'] = indicator.fund_id.map(name_dict)
         indicator = pd.merge(indicator,fund_ret, on='fund_id')
         indicator = indicator.sort_values('ret',ascending=False)
-        indicator['ret'] = indicator.ret.map(lambda x: str(round(x*10000,1))+'BP')
+        indicator['ret'] = indicator.ret.map(lambda x: str(round(x*10000,1))+'BP')        
+        fund_info['trim_name'] = fund_info.desc_name.map(lambda x : re.subn(r'[ABCDEFR]{1,2}(\(人民币\)|\(美元现汇\)|\(美元现钞\)|1|2|3)?$', '', x)[0])
+        trim_name_df = fund_info.set_index('fund_id')[['trim_name']]
+        fund_id_df = fund_info.set_index('trim_name')[['fund_id']]
+        fund_size = fund_size.tail(1).T
+        fund_size.columns = ['fund_size']
+        fund_size = fund_size.join(trim_name_df).groupby('trim_name').sum()
+        fund_size = fund_size.join(fund_id_df).set_index('fund_id')
+        indicator = indicator.set_index('fund_id').join(fund_size).reset_index()
         indicator['fund_size'] = indicator.fund_size.map(lambda x: str(round(x/1e8,1)) + '亿')
         indicator['alpha'] = indicator.alpha.map(lambda x: round(x,3))
         indicator['beta'] = indicator.beta.map(lambda x: round(x,3))
@@ -1296,10 +1304,6 @@ class ReportHelper:
                     },
             ]
         }
-
-
-
-
         fund_weight = pd.DataFrame(port_hold[port_name]['position']).set_index('fund_id')
         start_date = port_hold[port_name]['datetime']
         fund_nav = m.basic_data(func_name='get_fund_nav_with_date', fund_list=fund_weight.index.tolist(), start_date=start_date)
@@ -1338,10 +1342,23 @@ class ReportHelper:
         df.loc[:,'index_id'] = df.index.map(index_dic)
         df.loc[:,'weight'] = df.index.map(_fund_nav.loc[check_date])
         df = df.sort_values(by='fund_ret',ascending=False)
+        df['rets'] = df['fund_ret'] * df['weight']
         df['fund_ret'] = [str(i) + '%' for i in df['fund_ret']]
         df['weight'] = [str(round((i*100),2)) + '%' for i in df['weight']]
-        df = df[['begin_date','end_date','desc_name','index_id','fund_ret','weight']]
+        df['rets'] = [str(int(i*100)) + 'BP' for i in df['rets']]
+        df = df[['begin_date','end_date','desc_name','index_id','fund_ret','weight','rets']]
         fund_id_list = df.index.tolist()
         _df = m.view_data(func_name='get_daily_fund_daily_result', fund_id_list=fund_id_list).rename(columns={'基金ID':'fund_id'}).set_index('fund_id')
         df = df.join(_df)
-        return df
\ No newline at end of file
+        return df
+
+    def get_diff_between_position(self, df1, df2):
+        _df1 = df1[['rets']].rename(columns={'rets':'理论收益'}).reset_index()
+        _df1 = _df1[~_df1.index.duplicated(keep='first')]
+        _df2 = df2[['rets']].reset_index().rename(columns={'rets':'盈米收益','index':'fund_id'})
+        _df2 = _df2[~_df2.index.duplicated(keep='first')]
+        df_combine = _df1.merge(_df2, on='fund_id',how='outer').fillna(0)
+        desc_df = df1[['desc_name']].append(df2[['desc_name']]).drop_duplicates()
+        index_df = df1[['index_id']].append(df2[['index_id']])
+        df_combine = df_combine.set_index('fund_id').join(desc_df).join(index_df)
+        return df_combine
