@@ -1151,12 +1151,18 @@ class Calculator:
         try:
             if frequency == '日度':
                 rule = '1D'
+                if windows <= 2:
+                    return pandas.DataFrame()
                 windows = int(windows / 1)
             if frequency == '周度':
                 rule = '1W'
+                if windows <= 10:
+                    return pandas.DataFrame()
                 windows = int(windows / 5)
             if frequency == '月度':
                 rule = '1M'
+                if windows <= 40:
+                    return pandas.DataFrame()
                 windows = int(windows / 20)
 
             fund_navs_period = CalculatorBase.data_resample_weekly_nav(df=fund_navs, rule=rule)
@@ -1196,7 +1202,7 @@ class Calculator:
 
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from portfolio.get_rolling_corr')
-
+            return pandas.DataFrame()
 
     @staticmethod
     def get_product_rolling_corr(fund_navs, windows=20, period='周度', index_id='hs300'):
@@ -1212,6 +1218,11 @@ class Calculator:
                 fund_navs = fund_navs.join(index_price).sort_index()
             
             result = Calculator.get_rolling_corr(fund_navs, windows, period)
+            if result.empty:
+                return {
+                    'data':result,
+                    'details':{},
+                }
             if result.shape[0] > 50:
                 result = result.iloc[-50:]
             corr_details = {}
@@ -1248,18 +1259,28 @@ class Calculator:
 
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from calculator.get_product_rolling_corr')
+            return {
+                    'data':result,
+                    'details':{},
+                }
 
     @staticmethod
     def get_product_rolling_beta(fund_navs, windows=20, period='周度', index_id='hs300'):
         try:
             if period == '日度':
                 rule = '1D'
+                if windows <= 2:
+                    return pandas.DataFrame()
                 windows = int(windows / 1)
             if period == '周度':
                 rule = '1W'
+                if windows <= 10:
+                    return pandas.DataFrame()
                 windows = int(windows / 5)
             if period == '月度':
                 rule = '1M'
+                if windows <= 40:
+                    return pandas.DataFrame()
                 windows = int(windows / 20)
 
             basic = BasicDataApi()
@@ -1292,6 +1313,7 @@ class Calculator:
 
         except Exception as e:
             print(f'Failed to get data <err_msg> {e} from calculator.get_product_rolling_beta')
+            return pandas.DataFrame()
 
     @staticmethod
     def rolling_alpha_beta(x, res, df):
